==> activity-center-api-0.12.67-sjq-20210112.092413-5-sources.jar: cn/com/duiba/tuia/activity/center/api/dto/adx/PopularGroupDto.java <==
package cn.com.duiba.tuia.activity.center.api.dto.adx;

import java.io.Serializable;

/**
 * 推广组
 *
 * @author weny.cai
 * @date 2018/11/29 14:56
 **/
public class PopularGroupDto implements Serializable {

    private Long id;

    private String groupName;

    private Long mid;

    /** 是否开启预发券：0. 未开启 1. 已开启 **/
    private Integer preLoadAdvertStatus;

    private Integer switchState;

    private Integer adxType;

    /** 是否走新的ADX架构标识符 **/
    private boolean isUpgrade;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getGroupName() {
        return groupName;
    }

    public void setGroupName(String groupName) {
        this.groupName = groupName;
    }

    public Long getMid() {
        return mid;
    }

    public void setMid(Long mid) {
        this.mid = mid;
    }

    public Integer getPreLoadAdvertStatus() {
        return preLoadAdvertStatus;
    }

    public void setPreLoadAdvertStatus(Integer preLoadAdvertStatus) {
        this.preLoadAdvertStatus = preLoadAdvertStatus;
    }

    public Integer getSwitchState() {
        return switchState;
    }

    public void setSwitchState(Integer switchState) {
        this.switchState = switchState;
    }

    public Integer getAdxType() {
        return adxType;
    }

    public void setAdxType(Integer adxType) {
        this.adxType = adxType;
    }

    public boolean isUpgrade() {
        return isUpgrade;
    }

    public void setUpgrade(boolean upgrade) {
        isUpgrade = upgrade;
    }
}

==> activity-center-api-0.14.22-sjq-20211129.072839-1-sources.jar: cn/com/duiba/tuia/activity/center/api/dto/adx/PopularGroupDto.java <==
package cn.com.duiba.tuia.activity.center.api.dto.adx;

import java.io.Serializable;

/**
 * 推广组
 *
 * @author weny.cai
 * @date 2018/11/29 14:56
 **/
public class PopularGroupDto implements Serializable {

    private Long id;

    private String groupName;

    private Long mid;

    /** 是否开启预发券：0. 未开启 1. 已开启 **/
    private Integer preLoadAdvertStatus;

    private Integer switchState;

    private Integer adxType;

    /** 是否走新的ADX架构标识符 **/
    private boolean isUpgrade;

    /**
     * 默认交易模式，默认为RTB
     */
    private Integer defaultPmpType;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getGroupName() {
        return groupName;
    }

    public void setGroupName(String groupName) {
        this.groupName = groupName;
    }

    public Long getMid() {
        return mid;
    }

    public void setMid(Long mid) {
        this.mid = mid;
    }

    public Integer getPreLoadAdvertStatus() {
        return preLoadAdvertStatus;
    }

    public void setPreLoadAdvertStatus(Integer preLoadAdvertStatus) {
        this.preLoadAdvertStatus = preLoadAdvertStatus;
    }

    public Integer getSwitchState() {
        return switchState;
    }

    public void setSwitchState(Integer switchState) {
        this.switchState = switchState;
    }

    public Integer getAdxType() {
        return adxType;
    }

    public void setAdxType(Integer adxType) {
        this.adxType = adxType;
    }

    public boolean isUpgrade() {
        return isUpgrade;
    }

    public void setUpgrade(boolean upgrade) {
        isUpgrade = upgrade;
    }

    public Integer getDefaultPmpType() {
        return defaultPmpType;
    }

    public void setDefaultPmpType(Integer defaultPmpType) {
        this.defaultPmpType = defaultPmpType;
    }
}
